Unit Unit1;
(* -------------------------------------------------------- *)
Interface
(* -------------------------------------------------------- *)
Uses KolibriOS;
(* -------------------------------------------------------- *)
Const
  WINDOW_BORDER_SIZE = 5;

  CLOSE_BUTTON         = 1;
  CREATE_FOLDER_BUTTON = 2;
  CREATE_FILE_BUTTON   = 3;
  WRITE_FILE_BUTTON    = 4;

  TestFolderPath = '/rd/1/test_folder';
  TestFilePath = '/rd/1/test_folder/test_file.txt';
  TestData: Array [0..9] Of Char = 'Test100500';

  StrCreateFolderError   = 'CreateFolder error!     ';
  StrCreateFileError     = 'CreateFile error!       ';
  StrWriteFileError      = 'WriteFile error!        ';

  StrCreateFolderSuccess = 'Folder is created.      ';
  StrCreateFileSuccess   = 'File is created.        ';
  StrWriteFileSuccess    = 'Data is written to file.';
(* -------------------------------------------------------- *)
Var
  Window: TRect;
  Screen: TSize;
  StrCreateFolderResult: PChar;
  StrCreateFileResult: PChar;
  StrWriteFileResult: PChar;
(* -------------------------------------------------------- *)
Procedure Main;
Procedure On_Button;
Procedure On_Redraw;
Procedure DrawCreateFolderResult;
Procedure DrawCreateFileResult;
Procedure DrawWriteFileResult;
(* -------------------------------------------------------- *)
Implementation
(* -------------------------------------------------------- *)
Procedure Main;
Begin
  Screen := GetScreenSize();

  With Window, Screen Do
  Begin
    Right  := WINDOW_BORDER_SIZE + 320 + WINDOW_BORDER_SIZE;
    Bottom := GetSkinHeight + 130 + WINDOW_BORDER_SIZE;
    Left   := (Width  - Right)  Shr 1;
    Top    := (Height - Bottom) Shr 1;
  End;

  SetEventMask(EM_REDRAW + EM_BUTTON);

  StrCreateFolderResult := '';
  StrCreateFileResult   := '';
  StrWriteFileResult    := '';

  While TRUE Do Begin
    Case WaitEvent() Of
      REDRAW_EVENT: On_Redraw;
      BUTTON_EVENT: On_Button;
    End;
  End;
End;
(* -------------------------------------------------------- *)
Procedure On_Redraw;
Begin
  BeginDraw;

  With Window Do
    DrawWindow(Left, Top, Right, Bottom, 'CreateFolder CreateFile WriteFile', $00FFFFFF, WS_SKINNED_FIXED + WS_COORD_CLIENT + WS_CAPTION, CAPTION_MOVABLE);

  DrawButton(8, 8, 115, 33, $00DFDFFF, 0, CREATE_FOLDER_BUTTON);
  DrawButton(8, 48, 115, 33, $00DFFFDF, 0, CREATE_FILE_BUTTON);
  DrawButton(8, 88, 115, 33, $00FFDFDF, 0, WRITE_FILE_BUTTON);

  DrawText(13, 21, 'Create folder', $00000070, 0, DT_CP866_6X9 + DT_FILL_TRANSPARENT + DT_ZSTRING, 0);
  DrawText(13, 61, 'Create file', $00007000, 0, DT_CP866_6X9 + DT_FILL_TRANSPARENT + DT_ZSTRING, 0);
  DrawText(13, 101, 'Write data to file', $00700000, 0, DT_CP866_6X9 + DT_FILL_TRANSPARENT + DT_ZSTRING, 0);

  DrawCreateFolderResult;
  DrawCreateFileResult;
  DrawWriteFileResult;

  EndDraw;
End;
(* -------------------------------------------------------- *)
Procedure DrawCreateFolderResult;
Begin
  DrawText(150, 20, StrCreateFolderResult, $00101080, $00FFFFFF, DT_CP866_6X9 + DT_FILL_OPAQUE + DT_ZSTRING, 0);
End;
(* -------------------------------------------------------- *)
Procedure DrawCreateFileResult;
Begin
  DrawText(150, 60, StrCreateFileResult, $00108010, $00FFFFFF, DT_CP866_6X9 + DT_FILL_OPAQUE + DT_ZSTRING, 0);
End;
(* -------------------------------------------------------- *)
Procedure DrawWriteFileResult;
Begin
  DrawText(150, 100, StrWriteFileResult, $00801010, $00FFFFFF, DT_CP866_6X9 + DT_FILL_OPAQUE + DT_ZSTRING, 0);
End;
(* -------------------------------------------------------- *)
Procedure On_Button;
Var
  BytesWritten: Dword;
Begin
  Case GetButton().ID Of
    CLOSE_BUTTON:         ThreadTerminate;
    CREATE_FOLDER_BUTTON:
      Begin
        If CreateFolder(TestFolderPath) = 0 Then
          StrCreateFolderResult := StrCreateFolderSuccess
        Else
          StrCreateFolderResult := StrCreateFolderError;
        DrawCreateFolderResult;
      End;
    CREATE_FILE_BUTTON:
      Begin
        If CreateFile(TestFilePath) = 0 Then
          StrCreateFileResult := StrCreateFileSuccess
        Else
          StrCreateFileResult := StrCreateFileError;
        DrawCreateFileResult;
      End;
    WRITE_FILE_BUTTON:
      Begin
        If WriteFile(TestFilePath, TestData, SizeOf(TestData), 0, 0, BytesWritten) = 0 Then
          StrWriteFileResult := StrWriteFileSuccess
        Else
          StrWriteFileResult := StrWriteFileError;
        DrawWriteFileResult;
      End;
  End;
End;
(* -------------------------------------------------------- *)
End.